@@ -268,6 +268,9 @@ class Element:
     def afterCreateCombo(self):
         items = [c.qt for c in self.childs]
         self.qt.addItems(items)
+
+        if 'index' in self.attrsToDict.keys() and isinstance(self.attrsToDict['index'], ObservableBase):
+            self.qt.currentIndexChanged[int].connect(lambda v: self.attrsToDict['index'].setValue(v))
         self.bindAll()
 
     def createOption(self):
