@@ -64,7 +64,7 @@ class Parser:
             if ob_value:
                 arr_index = re.findall(r'.*\[(\d+)\]', ob_value)
                 if len(arr_index) > 0:
-                    value = getattr(self.models, ob_value.replace("[%d]" % arr_index[0], ''))[arr_index]
+                    value = getattr(self.models, ob_value.replace("[%s]" % arr_index[0], ''))[arr_index]
                 else:
                     value = getattr(self.models, ob_value)
             else:
